### Name: AssetsModelling
### Title: Modelling of Multivariate Asset Sets
### Aliases: AssetsModelling fASSETS fASSETS-class assetsSim assetsFit
###   assetsSelect assetsStats assetsMeanCov assetsTest print.fASSETS
###   plot.fASSETS summary.fASSETS
### Keywords: models

### ** Examples

## Not run: 
##D ## SOURCE("fPortfolio.101A-AssetsModelling")
##D 
##D ## berndtInvest -
##D    xmpPortfolio("\nStart: Load monthly data set of returns > ")
##D    data(berndtInvest)
##D    # Exclude Date, Market and Interest Rate columns from data frame,
##D    # then multiply by 100 for percentual returns ...
##D    berndtAssets = berndtInvest[, -c(1, 11, 18)]
##D    rownames(berndtAssets) = berndtInvest[, 1]
##D    head(berndtAssets)
##D     
##D ## assetsSelect -
##D    xmpPortfolio("\nNext: Select 4 most dissimilar assets from hclust > ")
##D    clustered = assetsSelect(berndtAssets, doplot = FALSE)
##D    myAssets = berndtAssets[, c(clustered$order[1:4])]
##D    colnames(myAssets)
##D    # Scatter and time series plot:
##D    par(mfrow = c(2, 1), cex = 0.7)
##D    plot(clustered)  
##D    myPrices = apply(myAssets, 2, cumsum)
##D    ts.plot(myPrices, main = "Selected Assets", 
##D      xlab = "Months starting 1978", ylab = "Price", col = 1:4)
##D    legend(0, 3, legend = colnames(myAssets), pch = "----", col = 1:4, cex = 1)
##D    
##D ## assetsStats -
##D    if (require(fBasics)) assetsStats(myAssets)
##D    
##D ## assetsSim -
##D    xmpPortfolio("\nNext: Fit a Skew Student-t > ")
##D    fit = assetsFit(myAssets)
##D    # Show Model Slot:
##D    fit @model
##D    # Simulate set with same properties:
##D    set.seed(1953)
##D    simAssets = assetsSim(n = 120, dim = 4, model = fit@model)
##D    head(simAssets)
##D    simPrices = apply(simAssets, 2, cumsum)
##D    ts.plot(simPrices, main = "Simulated Assets", 
##D      xlab = "Number of Months", ylab = "Simulated Price", col = 1:4)
##D    legend(0, 3, legend = colnames(simAssets), pch = "----", col = 1:4, cex = 1)
##D    
##D ## plot -
##D    xmpPortfolio("\nNext: Show Simulated Assets Plots > ")
##D    if (require(fExtremes)) {
##D      # Show Scatterplot:
##D      par(mfrow = c(1, 1), cex = 0.7)
##D      plot(fit, which = c(TRUE, FALSE, FALSE, FALSE, FALSE))
##D      # Show  QQ and PP Plots:
##D      par(mfrow = c(2, 2), cex = 0.7)
##D      plot(fit, which = !c(TRUE, FALSE, FALSE, FALSE, FALSE))
##D    }
## End(Not run)



